from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    author="Bastian Probian",
    author_email="contmp@me.com",
    long_description=long_description,
    long_description_content_type="text/markdown"
)
